# Clandestino Post

Main project [here](https://github.com/CenturyBoys/clandestino)

This project uses [motor](https://pypi.org/project/motor/) "^3.3.2" package to communicate with mongodb.

motor = "^3.3.2"